* [merged mm-hotfixes-stable] mm-migrate_device-return-number-of-migrating-pages-in-args-cpages.patch removed from -mm tree
@ 2022-11-23 2:53 Andrew Morton
0 siblings, 0 replies; only message in thread
From: Andrew Morton @ 2022-11-23 2:53 UTC (permalink / raw)
To: mm-commits, rcampbell, mpe, lyude, jhubbard, jgg, Felix.Kuehling,
bskeggs, alex.sierra, apopple, akpm
The quilt patch titled
Subject: mm/migrate_device: return number of migrating pages in args->cpages
has been removed from the -mm tree. Its filename was
mm-migrate_device-return-number-of-migrating-pages-in-args-cpages.patch
This patch was dropped because it was merged into the mm-hotfixes-stable branch
of git://git.kernel.org/pub/scm/linux/kernel/git/akpm/mm
------------------------------------------------------
From: Alistair Popple <apopple@nvidia.com>
Subject: mm/migrate_device: return number of migrating pages in args->cpages
Date: Fri, 11 Nov 2022 11:51:35 +1100
migrate_vma->cpages originally contained a count of the number of pages
migrating including non-present pages which can be populated directly on
the target.
Commit 241f68859656 ("mm/migrate_device.c: refactor migrate_vma and
migrate_device_coherent_page()") inadvertantly changed this to contain
just the number of pages that were unmapped. Usage of migrate_vma->cpages
isn't documented, but most drivers use it to see if all the requested
addresses can be migrated so restore the original behaviour.
Link: https://lkml.kernel.org/r/20221111005135.1344004-1-apopple@nvidia.com
Fixes: 241f68859656 ("mm/migrate_device.c: refactor migrate_vma and migrate_deivce_coherent_page()")
Signed-off-by: Alistair Popple <apopple@nvidia.com>
Reported-by: Ralph Campbell <rcampbell@nvidia.com>
Reviewed-by: Ralph Campbell <rcampbell@nvidia.com>
Cc: John Hubbard <jhubbard@nvidia.com>
Cc: Alex Sierra <alex.sierra@amd.com>
Cc: Ben Skeggs <bskeggs@redhat.com>
Cc: Felix Kuehling <Felix.Kuehling@amd.com>
Cc: Lyude Paul <lyude@redhat.com>
Cc: Jason Gunthorpe <jgg@nvidia.com>
Cc: Michael Ellerman <mpe@ellerman.id.au>
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
---
mm/migrate_device.c | 8 ++++++--
1 file changed, 6 insertions(+), 2 deletions(-)
--- a/mm/migrate_device.c~mm-migrate_device-return-number-of-migrating-pages-in-args-cpages
+++ a/mm/migrate_device.c
@@ -357,7 +357,8 @@ static bool migrate_vma_check_page(struc
}
/*
* Unmaps pages for migration. Returns number of unmapped pages.
*/
static unsigned long migrate_device_unmap(unsigned long *src_pfns,
unsigned long npages,
@@ -373,8 +374,11 @@ static unsigned long migrate_device_unma
struct page *page = migrate_pfn_to_page(src_pfns[i]);
struct folio *folio;
- if (!page)
+ if (!page) {
+ if (src_pfns[i] & MIGRATE_PFN_MIGRATE)
+ unmapped++;
continue;
+ }
/* ZONE_DEVICE pages are not on LRU */
if (!is_zone_device_page(page)) {
_
Patches currently in -mm which might be from apopple@nvidia.com are
^ permalink raw reply [flat|nested] only message in thread
only message in thread, other threads:[~2022-11-23 2:53 UTC | newest]
Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2022-11-23 2:53 [merged mm-hotfixes-stable] mm-migrate_device-return-number-of-migrating-pages-in-args-cpages.patch removed from -mm tree Andrew Morton
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
@@ -357,7 +357,8 @@ static bool migrate_vma_check_page(struc
}
/*
- * Unmaps pages for migration. Returns number of unmapped pages.
+ * Unmaps pages for migration. Returns number of source pfns marked as
+ * migrating.
*/
static unsigned long migrate_device_unmap(unsigned long *src_pfns,
all data and code used by this external index.